"Daniel Veillard",
"Eckehard Berns",
"Elliot Lee",
"Federico Mena",
"George Lebl",
"Havoc Pennington",
"Jaka Mocnik",
"Jens Christian Restemeier",
"Jonathan Blanford",
"Marc Ewing",
"Marius Vollmer",
"Michael Fulbright",
"Michael K. Johnson",
"Miguel de Icaza",
"Molaro Paolo",
"Owen Taylor",
"Radek Doulik",
"Seth Alves",
"Shawn Amundson",
"Szekeres Istvan",
"The Rasterman",
"Tim Janik",
"Tom Tromey",
"Tuomas Kuosmanen",
